@@ -26,6 +26,7 @@
 #include "vcaldrag.h"
 
 #include "kcalutils_debug.h"
+#include <KCalendarCore/MemoryCalendar>
 #include <KIconLoader>
 #include <KUrlMimeData>
 #include <QUrl>
@@ -38,7 +39,6 @@
 #include <QIcon>
 #include <QMimeData>
 #include <QTimeZone>
-#include <QWidget>
 
 using namespace KCalendarCore;
 using namespace KCalUtils;
@@ -51,7 +51,7 @@ using namespace KCalUtils;
 class KCalUtils::DndFactoryPrivate
 {
 public:
-    DndFactoryPrivate(const MemoryCalendar::Ptr &calendar)
+    DndFactoryPrivate(const Calendar::Ptr &calendar)
         : mCalendar(calendar)
     {
     }
@@ -116,32 +116,29 @@ public:
         return inc;
     }
 
-    MemoryCalendar::Ptr mCalendar;
+    const Calendar::Ptr mCalendar;
 };
 //@endcond
 
-DndFactory::DndFactory(const MemoryCalendar::Ptr &calendar)
+DndFactory::DndFactory(const Calendar::Ptr &calendar)
     : d(new KCalUtils::DndFactoryPrivate(calendar))
 {
 }
 
-DndFactory::~DndFactory()
-{
-    delete d;
-}
+DndFactory::~DndFactory() = default;
 
 QMimeData *DndFactory::createMimeData()
 {
-    auto *mimeData = new QMimeData;
+    auto mimeData = new QMimeData;
 
     ICalDrag::populateMimeData(mimeData, d->mCalendar);
 
     return mimeData;
 }
 
-QDrag *DndFactory::createDrag(QWidget *owner)
+QDrag *DndFactory::createDrag(QObject *owner)
 {
-    auto *drag = new QDrag(owner);
+    auto drag = new QDrag(owner);
     drag->setMimeData(createMimeData());
 
     return drag;
@@ -149,13 +146,13 @@ QDrag *DndFactory::createDrag(QWidget *owner)
 
 QMimeData *DndFactory::createMimeData(const Incidence::Ptr &incidence)
 {
-    MemoryCalendar::Ptr cal(new MemoryCalendar(d->mCalendar->timeZone()));
+    Calendar::Ptr cal(new MemoryCalendar(d->mCalendar->timeZone()));
     Incidence::Ptr i(incidence->clone());
     // strip recurrence id's, We don't want to drag the exception but the occurrence.
     i->setRecurrenceId({});
     cal->addIncidence(i);
 
-    auto *mimeData = new QMimeData;
+    auto mimeData = new QMimeData;
 
     ICalDrag::populateMimeData(mimeData, cal);
 
@@ -170,31 +167,31 @@ QMimeData *DndFactory::createMimeData(const Incidence::Ptr &incidence)
     return mimeData;
 }
 
-QDrag *DndFactory::createDrag(const Incidence::Ptr &incidence, QWidget *owner)
+QDrag *DndFactory::createDrag(const Incidence::Ptr &incidence, QObject *owner)
 {
-    auto *drag = new QDrag(owner);
+    auto drag = new QDrag(owner);
     drag->setMimeData(createMimeData(incidence));
     drag->setPixmap(QIcon::fromTheme(incidence->iconName()).pixmap(KIconLoader::SizeSmallMedium));
 
     return drag;
 }
 
-MemoryCalendar::Ptr DndFactory::createDropCalendar(const QMimeData *mimeData)
+Calendar::Ptr DndFactory::createDropCalendar(const QMimeData *mimeData)
 {
     if (mimeData) {
-        MemoryCalendar::Ptr calendar(new MemoryCalendar(QTimeZone::systemTimeZone()));
+        Calendar::Ptr calendar(new MemoryCalendar(QTimeZone::systemTimeZone()));
 
         if (ICalDrag::fromMimeData(mimeData, calendar) || VCalDrag::fromMimeData(mimeData, calendar)) {
             return calendar;
         }
     }
 
-    return MemoryCalendar::Ptr();
+    return Calendar::Ptr();
 }
 
-MemoryCalendar::Ptr DndFactory::createDropCalendar(QDropEvent *dropEvent)
+Calendar::Ptr DndFactory::createDropCalendar(QDropEvent *dropEvent)
 {
-    MemoryCalendar::Ptr calendar(createDropCalendar(dropEvent->mimeData()));
+    Calendar::Ptr calendar(createDropCalendar(dropEvent->mimeData()));
     if (calendar) {
         dropEvent->accept();
         return calendar;
@@ -206,7 +203,7 @@ Event::Ptr DndFactory::createDropEvent(const QMimeData *mimeData)
 {
     // qCDebug(KCALUTILS_LOG);
     Event::Ptr event;
-    MemoryCalendar::Ptr calendar(createDropCalendar(mimeData));
+    Calendar::Ptr calendar(createDropCalendar(mimeData));
 
     if (calendar) {
         Event::List events = calendar->events();
@@ -232,7 +229,7 @@ Todo::Ptr DndFactory::createDropTodo(const QMimeData *mimeData)
 {
     // qCDebug(KCALUTILS_LOG);
     Todo::Ptr todo;
-    MemoryCalendar::Ptr calendar(createDropCalendar(mimeData));
+    Calendar::Ptr calendar(createDropCalendar(mimeData));
 
     if (calendar) {
         Todo::List todos = calendar->todos();
@@ -280,7 +277,7 @@ bool DndFactory::copyIncidences(const Incidence::List &incidences)
 {
     QClipboard *clipboard = QApplication::clipboard();
     Q_ASSERT(clipboard);
-    MemoryCalendar::Ptr calendar(new MemoryCalendar(d->mCalendar->timeZone()));
+    Calendar::Ptr calendar(new MemoryCalendar(d->mCalendar->timeZone()));
 
     Incidence::List::ConstIterator it;
     const Incidence::List::ConstIterator end(incidences.constEnd());
@@ -290,7 +287,7 @@ bool DndFactory::copyIncidences(const Incidence::List &incidences)
         }
     }
 
-    auto *mimeData = new QMimeData;
+    auto mimeData = new QMimeData;
 
     ICalDrag::populateMimeData(mimeData, calendar);
 
@@ -313,7 +310,7 @@ Incidence::List DndFactory::pasteIncidences(const QDateTime &newDateTime, PasteF
 {
     QClipboard *clipboard = QApplication::clipboard();
     Q_ASSERT(clipboard);
-    MemoryCalendar::Ptr calendar(createDropCalendar(clipboard->mimeData()));
+    Calendar::Ptr calendar(createDropCalendar(clipboard->mimeData()));
     Incidence::List list;
 
     if (!calendar) {
@@ -355,7 +352,7 @@ Incidence::List DndFactory::pasteIncidences(const QDateTime &newDateTime, PasteF
 Incidence::Ptr DndFactory::pasteIncidence(const QDateTime &newDateTime, PasteFlags pasteOptions)
 {
     QClipboard *clipboard = QApplication::clipboard();
-    MemoryCalendar::Ptr calendar(createDropCalendar(clipboard->mimeData()));
+    Calendar::Ptr calendar(createDropCalendar(clipboard->mimeData()));
 
     if (!calendar) {
         qCDebug(KCALUTILS_LOG) << "Can't parse clipboard";
